@@ -441,15 +441,6 @@
     return V instanceof SharedArrayBuffer;
   }
 
-  function isArrayBufferDetached(V) {
-    try {
-      new Uint8Array(V);
-      return false;
-    } catch {
-      return true;
-    }
-  }
-
   converters.ArrayBuffer = (V, opts = {}) => {
     if (!isNonSharedArrayBuffer(V)) {
       if (opts.allowShared && !isSharedArrayBuffer(V)) {
@@ -461,9 +452,6 @@
       }
       throw makeException(TypeError, "is not an ArrayBuffer", opts);
     }
-    if (isArrayBufferDetached(V)) {
-      throw makeException(TypeError, "is a detached ArrayBuffer", opts);
-    }
 
     return V;
   };
@@ -480,13 +468,6 @@
         opts,
       );
     }
-    if (isArrayBufferDetached(V.buffer)) {
-      throw makeException(
-        TypeError,
-        "is backed by a detached ArrayBuffer",
-        opts,
-      );
-    }
 
     return V;
   };
@@ -529,13 +510,6 @@
             opts,
           );
         }
-        if (isArrayBufferDetached(V.buffer)) {
-          throw makeException(
-            TypeError,
-            "is a view on a detached ArrayBuffer",
-            opts,
-          );
-        }
 
         return V;
       };
@@ -561,13 +535,6 @@
       );
     }
 
-    if (isArrayBufferDetached(V.buffer)) {
-      throw makeException(
-        TypeError,
-        "is a view on a detached ArrayBuffer",
-        opts,
-      );
-    }
     return V;
   };
 
@@ -581,13 +548,6 @@
         );
       }
 
-      if (isArrayBufferDetached(V.buffer)) {
-        throw makeException(
-          TypeError,
-          "is a view on a detached ArrayBuffer",
-          opts,
-        );
-      }
       return V;
     }
 
@@ -609,9 +569,6 @@
         opts,
       );
     }
-    if (isArrayBufferDetached(V)) {
-      throw makeException(TypeError, "is a detached ArrayBuffer", opts);
-    }
 
     return V;
   };
